@@ -13,7 +13,6 @@ use glib::prelude::*;
 use glib::translate::*;
 use libc::c_void;
 use std::cmp;
-use std::convert;
 use std::ptr;
 
 use futures_core::{Future, Stream};
@@ -35,6 +34,7 @@ glib::wrapper! {
 impl ClockId {
     #[doc(alias = "get_time")]
     #[doc(alias = "gst_clock_id_get_time")]
+    #[doc(alias = "GST_CLOCK_ENTRY_TIME")]
     pub fn time(&self) -> ClockTime {
         unsafe {
             try_from_glib(ffi::gst_clock_id_get_time(self.to_glib_none().0))
@@ -56,6 +56,7 @@ impl ClockId {
         }
     }
 
+    #[doc(alias = "gst_clock_id_compare_func")]
     pub fn compare_by_time(&self, other: &Self) -> cmp::Ordering {
         unsafe {
             let res = ffi::gst_clock_id_compare_func(self.to_glib_none().0, other.to_glib_none().0);
@@ -84,6 +85,7 @@ impl ClockId {
     }
 
     #[doc(alias = "get_type")]
+    #[doc(alias = "GST_CLOCK_ENTRY_TYPE")]
     pub fn type_(&self) -> ClockEntryType {
         unsafe {
             let ptr: *mut ffi::GstClockEntry = self.to_glib_none().0 as *mut _;
@@ -92,6 +94,7 @@ impl ClockId {
     }
 
     #[doc(alias = "get_status")]
+    #[doc(alias = "GST_CLOCK_ENTRY_STATUS")]
     pub fn status(&self) -> &AtomicClockReturn {
         unsafe {
             let ptr: *mut ffi::GstClockEntry = self.to_glib_none().0 as *mut _;
@@ -118,7 +121,7 @@ impl From<SingleShotClockId> for ClockId {
     }
 }
 
-impl convert::TryFrom<ClockId> for SingleShotClockId {
+impl TryFrom<ClockId> for SingleShotClockId {
     type Error = glib::BoolError;
 
     fn try_from(id: ClockId) -> Result<SingleShotClockId, glib::BoolError> {
@@ -131,6 +134,7 @@ impl convert::TryFrom<ClockId> for SingleShotClockId {
 }
 
 impl SingleShotClockId {
+    #[doc(alias = "gst_clock_id_compare_func")]
     pub fn compare_by_time(&self, other: &Self) -> cmp::Ordering {
         self.0.compare_by_time(&other.0)
     }
@@ -228,7 +232,7 @@ impl From<PeriodicClockId> for ClockId {
     }
 }
 
-impl convert::TryFrom<ClockId> for PeriodicClockId {
+impl TryFrom<ClockId> for PeriodicClockId {
     type Error = glib::BoolError;
 
     fn try_from(id: ClockId) -> Result<PeriodicClockId, glib::BoolError> {
@@ -242,6 +246,7 @@ impl convert::TryFrom<ClockId> for PeriodicClockId {
 
 impl PeriodicClockId {
     #[doc(alias = "get_interval")]
+    #[doc(alias = "GST_CLOCK_ENTRY_INTERVAL")]
     pub fn interval(&self) -> ClockTime {
         unsafe {
             let ptr: *mut ffi::GstClockEntry = self.to_glib_none().0 as *mut _;
@@ -249,6 +254,7 @@ impl PeriodicClockId {
         }
     }
 
+    #[doc(alias = "gst_clock_id_compare_func")]
     pub fn compare_by_time(&self, other: &Self) -> cmp::Ordering {
         self.0.compare_by_time(&other.0)
     }
