@@ -2,19 +2,29 @@
 
 use glib::translate::*;
 use glib::StaticType;
+use muldiv::MulDiv;
 use num_integer::div_rem;
+use opt_ops::prelude::*;
+use std::borrow::Borrow;
 use std::io::{self, prelude::*};
+use std::ops;
 use std::time::Duration;
-use std::{cmp, convert, fmt, str};
+use std::{cmp, fmt, str};
 
-#[derive(PartialEq, Eq, PartialOrd, Ord, Hash, Clone, Copy, Debug, Default)]
+#[derive(PartialEq, Eq, PartialOrd, Ord, Hash, Clone, Copy, Default)]
 pub struct ClockTime(pub(crate) u64);
 
 impl ClockTime {
+    #[doc(alias = "GST_SECOND")]
     pub const SECOND: ClockTime = ClockTime(1_000_000_000);
+    #[doc(alias = "GST_MSECOND")]
     pub const MSECOND: ClockTime = ClockTime(1_000_000);
+    #[doc(alias = "GST_USECOND")]
     pub const USECOND: ClockTime = ClockTime(1_000);
+    #[doc(alias = "GST_NSECOND")]
     pub const NSECOND: ClockTime = ClockTime(1);
+    // checker-ignore-item
+    pub const MAX: ClockTime = ClockTime(ffi::GST_CLOCK_TIME_NONE - 1);
 
     pub const fn hours(self) -> u64 {
         self.0 / Self::SECOND.0 / 60 / 60
@@ -61,38 +71,6 @@ impl ClockTime {
     }
 }
 
-macro_rules! option_glib_newtype_from_to {
-    ($type_:ident, $none_value:expr) => {
-        #[doc(hidden)]
-        impl IntoGlib for $type_ {
-            type GlibType = u64;
-
-            fn into_glib(self) -> u64 {
-                self.0
-            }
-        }
-
-        #[doc(hidden)]
-        impl OptionIntoGlib for $type_ {
-            const GLIB_NONE: u64 = $none_value;
-        }
-
-        #[doc(hidden)]
-        impl TryFromGlib<u64> for $type_ {
-            type Error = GlibNoneError;
-            #[inline]
-            unsafe fn try_from_glib(val: u64) -> Result<Self, GlibNoneError> {
-                skip_assert_initialized!();
-                if val == $none_value {
-                    return Err(GlibNoneError);
-                }
-
-                Ok($type_(val))
-            }
-        }
-    };
-}
-
 option_glib_newtype_from_to!(ClockTime, ffi::GST_CLOCK_TIME_NONE);
 
 impl glib::value::ValueType for ClockTime {
@@ -176,7 +154,7 @@ impl fmt::Display for DurationError {
 
 impl std::error::Error for DurationError {}
 
-impl convert::TryFrom<Duration> for ClockTime {
+impl TryFrom<Duration> for ClockTime {
     type Error = DurationError;
 
     fn try_from(d: Duration) -> Result<Self, Self::Error> {
@@ -193,7 +171,7 @@ impl convert::TryFrom<Duration> for ClockTime {
     }
 }
 
-impl convert::From<ClockTime> for Duration {
+impl From<ClockTime> for Duration {
     fn from(t: ClockTime) -> Self {
         skip_assert_initialized!();
 
@@ -201,77 +179,22 @@ impl convert::From<ClockTime> for Duration {
     }
 }
 
-macro_rules! impl_common_ops_for_newtype_u64(
-    ($name:ident) => {
-        impl $name {
-            pub const ZERO: Self = Self(0);
-            pub const NONE: Option<Self> = None;
-
-            pub const fn is_zero(self) -> bool {
-                self.0 == Self::ZERO.0
-            }
-
-            #[must_use = "this returns the result of the operation, without modifying the original"]
-            #[inline]
-            // FIXME Can't use `map` in a `const fn` as of rustc 1.53.0-beta.2
-            #[allow(clippy::manual_map)]
-            pub const fn checked_add(self, rhs: Self) -> Option<Self> {
-                match self.0.checked_add(rhs.0) {
-                    Some(res) => Some(Self(res)),
-                    None => None,
-                }
-            }
-
-            #[must_use = "this returns the result of the operation, without modifying the original"]
-            #[inline]
-            pub const fn saturating_add(self, rhs: Self) -> Self {
-                Self(self.0.saturating_add(rhs.0))
-            }
-
-            #[must_use = "this returns the result of the operation, without modifying the original"]
-            #[inline]
-            pub const fn wrapping_add(self, rhs: Self) -> Self {
-                Self(self.0.wrapping_add(rhs.0))
-            }
-
-            #[must_use = "this returns the result of the operation, without modifying the original"]
-            #[inline]
-            // FIXME Can't use `map` in a `const fn` as of rustc 1.53.0-beta.2
-            #[allow(clippy::manual_map)]
-            pub const fn checked_sub(self, rhs: Self) -> Option<Self> {
-                match self.0.checked_sub(rhs.0) {
-                    Some(res) => Some(Self(res)),
-                    None => None,
-                }
-            }
-
-            #[must_use = "this returns the result of the operation, without modifying the original"]
-            #[inline]
-            pub const fn saturating_sub(self, rhs: Self) -> Self {
-                Self(self.0.saturating_sub(rhs.0))
-            }
-
-            #[must_use = "this returns the result of the operation, without modifying the original"]
-            #[inline]
-            pub const fn wrapping_sub(self, rhs: Self) -> Self {
-                Self(self.0.wrapping_sub(rhs.0))
-            }
-        }
-    };
-);
-
-impl_common_ops_for_newtype_u64!(ClockTime);
+impl_common_ops_for_newtype_uint!(ClockTime, u64);
 
+// rustdoc-stripper-ignore-next
 /// Tell [`pad_clocktime`] what kind of time we're formatting
 enum Sign {
+    // rustdoc-stripper-ignore-next
     /// An undefined time (`None`)
     Undefined,
 
+    // rustdoc-stripper-ignore-next
     /// A non-negative time (zero or greater)
     NonNegative,
 
     // For a future ClockTimeDiff formatting
     #[allow(dead_code)]
+    // rustdoc-stripper-ignore-next
     /// A negative time (below zero)
     Negative,
 }
@@ -281,6 +204,7 @@ enum Sign {
 // TODO: Would be useful for formatting ClockTimeDiff
 // if it was a new type instead of an alias for i64
 //
+// rustdoc-stripper-ignore-next
 /// Performs the correct padding for a clock time which has already been
 /// emitted into a str, as by [`write_clocktime`]. The str should *not*
 /// contain the sign; that will be added by this method.
@@ -347,6 +271,7 @@ fn pad_clocktime(f: &mut fmt::Formatter<'_>, sign: Sign, buf: &str) -> fmt::Resu
     Ok(())
 }
 
+// rustdoc-stripper-ignore-next
 /// Writes an unpadded, signless clocktime string with the given precision
 fn write_clocktime<W: io::Write>(
     mut writer: W,
@@ -419,7 +344,12 @@ impl fmt::Display for ClockTime {
     }
 }
 
-#[derive(Debug)]
+impl fmt::Debug for ClockTime {
+    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
+        fmt::Display::fmt(self, f)
+    }
+}
+
 pub struct DisplayableOptClockTime(Option<ClockTime>);
 
 impl fmt::Display for DisplayableOptClockTime {
@@ -428,6 +358,12 @@ impl fmt::Display for DisplayableOptClockTime {
     }
 }
 
+impl fmt::Debug for DisplayableOptClockTime {
+    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
+        fmt::Display::fmt(self, f)
+    }
+}
+
 impl crate::utils::Displayable for Option<ClockTime> {
     type DisplayImpl = DisplayableOptClockTime;
 
@@ -444,123 +380,239 @@ impl crate::utils::Displayable for ClockTime {
     }
 }
 
+impl std::iter::Sum for ClockTime {
+    fn sum<I: Iterator<Item = Self>>(iter: I) -> Self {
+        skip_assert_initialized!();
+        iter.fold(ClockTime::ZERO, |a, b| a + b)
+    }
+}
+
 #[cfg(test)]
 mod tests {
     use super::*;
 
+    const CT_1: ClockTime = ClockTime::from_nseconds(1);
+    const CT_2: ClockTime = ClockTime::from_nseconds(2);
+    const CT_3: ClockTime = ClockTime::from_nseconds(3);
+    const CT_10: ClockTime = ClockTime::from_nseconds(10);
+    const CT_20: ClockTime = ClockTime::from_nseconds(20);
+    const CT_30: ClockTime = ClockTime::from_nseconds(30);
+
     #[test]
     fn opt_time_clock() {
-        let ct_1 = ClockTime(1);
-        let opt_ct_none: Option<ClockTime> = None;
-
-        assert_eq!(ct_1.into_glib(), 1);
-        assert_eq!(Some(ct_1).into_glib(), 1);
-        assert_eq!(opt_ct_none.into_glib(), ffi::GST_CLOCK_TIME_NONE);
+        assert_eq!(CT_1.into_glib(), 1);
+        assert_eq!(Some(CT_1).into_glib(), 1);
+        assert_eq!(ClockTime::NONE.into_glib(), ffi::GST_CLOCK_TIME_NONE);
 
         let ct_1_from: ClockTime = unsafe { try_from_glib(1u64) }.unwrap();
-        assert_eq!(ct_1_from, ct_1);
+        assert_eq!(ct_1_from, CT_1);
 
         let opt_ct_some: Option<ClockTime> = unsafe { from_glib(1u64) };
-        assert_eq!(opt_ct_some, Some(ct_1));
+        assert_eq!(opt_ct_some, Some(CT_1));
 
-        let opt_ct_none: Option<ClockTime> = unsafe { from_glib(ffi::GST_CLOCK_TIME_NONE) };
-        assert_eq!(opt_ct_none, None);
+        let ct_none: Option<ClockTime> = unsafe { from_glib(ffi::GST_CLOCK_TIME_NONE) };
+        assert_eq!(ct_none, None);
     }
 
     #[test]
     #[allow(clippy::eq_op, clippy::op_ref)]
     fn ops() {
-        let ct_10 = 10 * ClockTime::MSECOND;
-        let ct_20 = 20 * ClockTime::MSECOND;
-        let ct_30 = 30 * ClockTime::MSECOND;
-
-        assert_eq!(ct_10 + ct_20, ct_30);
-        assert_eq!(ct_10 + &ct_20, ct_30);
-        assert_eq!(&ct_10 + &ct_20, ct_30);
-        assert_eq!(ct_30 - ct_20, ct_10);
-        assert_eq!(ct_30 - ct_30, ClockTime::ZERO);
-        assert_eq!(ct_10 * 3, ct_30);
-        assert_eq!(3 * ct_10, ct_30);
-        assert_eq!(3 * &ct_10, ct_30);
-        assert_eq!(ct_30.nseconds(), 30_000_000);
+        assert_eq!(CT_10 + CT_20, CT_30);
+        assert_eq!(CT_10 + &CT_20, CT_30);
+        assert_eq!(&CT_10 + &CT_20, CT_30);
+        assert_eq!(CT_30 - CT_20, CT_10);
+        assert_eq!(CT_30 - CT_30, ClockTime::ZERO);
+        assert_eq!(CT_10 * 3, CT_30);
+        assert_eq!(3 * CT_10, CT_30);
+        assert_eq!(3 * &CT_10, CT_30);
+        assert_eq!(CT_30.nseconds(), 30);
     }
 
     #[test]
     fn checked_ops() {
-        let ct_1 = ClockTime::from_nseconds(1);
-        let ct_2 = ClockTime::from_nseconds(2);
+        assert_eq!(CT_1.checked_add(CT_1), Some(CT_2));
 
-        let ct_max = ClockTime::from_nseconds(std::u64::MAX);
+        assert_eq!(CT_1.opt_checked_add(CT_1), Ok(Some(CT_2)));
+        assert_eq!(CT_1.opt_checked_add(Some(CT_1)), Ok(Some(CT_2)));
+        assert_eq!(Some(CT_1).opt_checked_add(Some(CT_1)), Ok(Some(CT_2)));
+        assert_eq!(CT_1.opt_checked_add(None), Ok(None));
+        assert_eq!(Some(CT_1).opt_checked_add(None), Ok(None));
 
-        assert_eq!(ct_1.checked_add(ct_1), Some(ct_2));
-        assert_eq!(ct_1.checked_add(ct_1), Some(ct_2));
-        assert!(ct_max.checked_add(ct_1).is_none());
+        assert!(ClockTime::MAX.checked_add(CT_1).is_none());
+        assert_eq!(
+            ClockTime::MAX.opt_checked_add(Some(CT_1)),
+            Err(opt_ops::Error::Overflow)
+        );
 
-        assert_eq!(ct_2.checked_sub(ct_1), Some(ct_1));
-        assert_eq!(ct_2.checked_sub(ct_1), Some(ct_1));
-        assert!(ct_1.checked_sub(ct_2).is_none());
+        assert_eq!(CT_2.checked_sub(CT_1), Some(CT_1));
+
+        assert_eq!(CT_2.opt_checked_sub(CT_1), Ok(Some(CT_1)));
+        assert_eq!(CT_2.opt_checked_sub(Some(CT_1)), Ok(Some(CT_1)));
+        assert_eq!(Some(CT_2).opt_checked_sub(CT_1), Ok(Some(CT_1)));
+        assert_eq!(Some(CT_2).opt_checked_sub(Some(CT_1)), Ok(Some(CT_1)));
+        assert_eq!(CT_2.opt_checked_sub(None), Ok(None));
+        assert_eq!(Some(CT_2).opt_checked_sub(None), Ok(None));
+
+        assert!(CT_1.checked_sub(CT_2).is_none());
+        assert_eq!(
+            Some(CT_1).opt_checked_sub(CT_2),
+            Err(opt_ops::Error::Overflow)
+        );
+    }
+
+    #[test]
+    fn overflowing_ops() {
+        assert_eq!(CT_1.overflowing_add(CT_2), (CT_3, false));
+        assert_eq!(CT_1.opt_overflowing_add(Some(CT_2)), Some((CT_3, false)));
+        assert_eq!(Some(CT_1).opt_overflowing_add(CT_2), Some((CT_3, false)));
+        assert_eq!(
+            Some(CT_1).opt_overflowing_add(Some(CT_2)),
+            Some((CT_3, false))
+        );
+        assert_eq!(ClockTime::NONE.opt_overflowing_add(CT_2), None);
+        assert_eq!(CT_1.opt_overflowing_add(ClockTime::NONE), None);
+
+        assert_eq!(
+            ClockTime::MAX.overflowing_add(CT_1),
+            (ClockTime::ZERO, true)
+        );
+        assert_eq!(
+            Some(ClockTime::MAX).opt_overflowing_add(Some(CT_1)),
+            Some((ClockTime::ZERO, true)),
+        );
+
+        assert_eq!(CT_3.overflowing_sub(CT_2), (CT_1, false));
+        assert_eq!(CT_3.opt_overflowing_sub(Some(CT_2)), Some((CT_1, false)));
+        assert_eq!(Some(CT_3).opt_overflowing_sub(CT_2), Some((CT_1, false)));
+        assert_eq!(
+            Some(CT_3).opt_overflowing_sub(Some(CT_2)),
+            Some((CT_1, false))
+        );
+        assert_eq!(
+            Some(CT_3).opt_overflowing_sub(&Some(CT_2)),
+            Some((CT_1, false))
+        );
+        assert_eq!(ClockTime::NONE.opt_overflowing_sub(CT_2), None);
+        assert_eq!(CT_2.opt_overflowing_sub(ClockTime::NONE), None);
+
+        assert_eq!(CT_1.overflowing_sub(CT_2), (ClockTime::MAX, true));
+        assert_eq!(
+            Some(CT_1).opt_overflowing_sub(CT_2),
+            Some((ClockTime::MAX, true))
+        );
     }
 
     #[test]
     fn saturating_ops() {
-        let ct_1 = ClockTime::from_nseconds(1);
-        let ct_2 = ClockTime::from_nseconds(2);
-        let ct_3 = ClockTime::from_nseconds(3);
+        assert_eq!(CT_1.saturating_add(CT_2), CT_3);
 
-        let ct_max = ClockTime::from_nseconds(std::u64::MAX);
+        assert_eq!(CT_1.opt_saturating_add(Some(CT_2)), Some(CT_3));
+        assert_eq!(Some(CT_1).opt_saturating_add(Some(CT_2)), Some(CT_3));
+        assert_eq!(Some(CT_1).opt_saturating_add(None), None);
 
-        assert_eq!(ct_1.saturating_add(ct_2), ct_3);
-        assert_eq!(ct_1.saturating_add(ct_2), ct_3);
-        assert_eq!(ct_max.saturating_add(ct_1), ct_max);
+        assert_eq!(ClockTime::MAX.saturating_add(CT_1), ClockTime::MAX);
+        assert_eq!(
+            Some(ClockTime::MAX).opt_saturating_add(Some(CT_1)),
+            Some(ClockTime::MAX)
+        );
 
-        assert_eq!(ct_3.saturating_sub(ct_2), ct_1);
-        assert_eq!(ct_3.saturating_sub(ct_2), ct_1);
-        assert!(ct_1.saturating_sub(ct_2).is_zero());
+        assert_eq!(CT_3.saturating_sub(CT_2), CT_1);
+        assert_eq!(CT_3.opt_saturating_sub(Some(CT_2)), Some(CT_1));
+        assert_eq!(Some(CT_3).opt_saturating_sub(Some(CT_2)), Some(CT_1));
+        assert_eq!(Some(CT_3).opt_saturating_sub(None), None);
+
+        assert!(CT_1.saturating_sub(CT_2).is_zero());
+        assert_eq!(
+            Some(CT_1).opt_saturating_sub(Some(CT_2)),
+            Some(ClockTime::ZERO)
+        );
     }
 
     #[test]
     fn wrapping_ops() {
-        let ct_1 = ClockTime::NSECOND;
-        let ct_2 = 2 * ClockTime::NSECOND;
-        let ct_3 = 3 * ClockTime::NSECOND;
+        assert_eq!(CT_1.wrapping_add(CT_2), CT_3);
+        assert_eq!(CT_1.opt_wrapping_add(CT_2), Some(CT_3));
+        assert_eq!(Some(CT_1).opt_wrapping_add(CT_2), Some(CT_3));
+        assert_eq!(Some(CT_1).opt_wrapping_add(Some(CT_2)), Some(CT_3));
+        assert_eq!(Some(CT_1).opt_wrapping_add(None), None);
 
-        let ct_max = ClockTime::from_nseconds(std::u64::MAX);
+        assert_eq!(ClockTime::MAX.wrapping_add(CT_1), ClockTime::ZERO);
+        assert_eq!(
+            Some(ClockTime::MAX).opt_wrapping_add(Some(CT_1)),
+            Some(ClockTime::ZERO)
+        );
 
-        assert_eq!(ct_1.wrapping_add(ct_2), ct_3);
-        assert_eq!(ct_1.wrapping_add(ct_2), ct_3);
-        assert_eq!(ct_max.wrapping_add(ct_1), ClockTime::ZERO);
+        assert_eq!(CT_3.wrapping_sub(CT_2), CT_1);
+        assert_eq!(CT_3.opt_wrapping_sub(CT_2), Some(CT_1));
+        assert_eq!(Some(CT_3).opt_wrapping_sub(CT_2), Some(CT_1));
+        assert_eq!(Some(CT_3).opt_wrapping_sub(Some(CT_2)), Some(CT_1));
+        assert_eq!(Some(CT_3).opt_wrapping_sub(None), None);
 
-        assert_eq!(ct_3.wrapping_sub(ct_2), ct_1);
-        assert_eq!(ct_3.wrapping_sub(ct_2), ct_1);
-        assert_eq!(ct_1.wrapping_sub(ct_2), ct_max);
+        assert_eq!(CT_1.wrapping_sub(CT_2), ClockTime::MAX);
+        assert_eq!(
+            Some(CT_1).opt_wrapping_sub(Some(CT_2)),
+            Some(ClockTime::MAX)
+        );
     }
 
     #[test]
+    #[allow(clippy::nonminimal_bool)]
     fn comp() {
-        let ct_0 = ClockTime::ZERO;
-        let ct_2 = 2 * ClockTime::NSECOND;
-        let ct_3 = 3 * ClockTime::NSECOND;
-        let opt_ct_none: Option<ClockTime> = None;
+        assert!(ClockTime::ZERO < CT_2);
+        assert!(Some(ClockTime::ZERO) < Some(CT_2));
+        assert!(CT_2 < CT_3);
+        assert!(Some(CT_2) < Some(CT_3));
+        assert!(ClockTime::ZERO < CT_3);
+        assert!(Some(ClockTime::ZERO) < Some(CT_3));
 
-        assert!(ct_0 < ct_2);
-        assert!(Some(ct_0) < Some(ct_2));
-        assert!(ct_2 < ct_3);
-        assert!(Some(ct_2) < Some(ct_3));
-        assert!(ct_0 < ct_3);
-        assert!(Some(ct_0) < Some(ct_3));
+        assert_eq!(Some(CT_2).opt_lt(Some(CT_3)), Some(true));
+        assert_eq!(Some(CT_3).opt_lt(CT_2), Some(false));
+        assert_eq!(Some(CT_2).opt_le(Some(CT_3)), Some(true));
+        assert_eq!(Some(CT_3).opt_le(CT_3), Some(true));
 
-        assert!(ct_3 > ct_2);
-        assert!(Some(ct_3) > Some(ct_2));
-        assert!(ct_2 > ct_0);
-        assert!(Some(ct_2) > Some(ct_0));
-        assert!(ct_3 > ct_0);
-        assert!(Some(ct_3) > Some(ct_0));
+        assert!(CT_3 > CT_2);
+        assert!(Some(CT_3) > Some(CT_2));
+        assert!(CT_2 > ClockTime::ZERO);
+        assert!(Some(CT_2) > Some(ClockTime::ZERO));
+        assert!(CT_3 > ClockTime::ZERO);
+        assert!(Some(CT_3) > Some(ClockTime::ZERO));
 
-        assert!(!(opt_ct_none < None));
-        assert!(!(opt_ct_none > None));
+        assert!(!(ClockTime::NONE > None));
         // This doesn't work due to the `PartialOrd` impl on `Option<T>`
-        //assert_eq!(Some(ct_0) > opt_ct_none, false);
-        assert!(!(Some(ct_0) < opt_ct_none));
+        //assert_eq!(Some(ClockTime::ZERO) > ClockTime::ZERO, false);
+        assert!(!(Some(ClockTime::ZERO) < ClockTime::NONE));
+        assert_eq!(Some(CT_3).opt_gt(Some(CT_2)), Some(true));
+        assert_eq!(Some(CT_3).opt_ge(Some(CT_2)), Some(true));
+        assert_eq!(Some(CT_3).opt_ge(CT_3), Some(true));
+
+        assert!(!(ClockTime::NONE < None));
+        assert!(!(ClockTime::NONE > None));
+
+        // This doesn't work due to the `PartialOrd` impl on `Option<T>`
+        //assert!(Some(ClockTime::ZERO) > ClockTime::NONE, false);
+        // Use opt_gt instead.
+        assert_eq!(Some(ClockTime::ZERO).opt_gt(ClockTime::NONE), None);
+        assert_eq!(ClockTime::ZERO.opt_gt(ClockTime::NONE), None);
+        assert_eq!(ClockTime::ZERO.opt_ge(ClockTime::NONE), None);
+        assert_eq!(ClockTime::NONE.opt_gt(Some(ClockTime::ZERO)), None);
+        assert_eq!(ClockTime::NONE.opt_gt(ClockTime::ZERO), None);
+        assert_eq!(ClockTime::NONE.opt_ge(ClockTime::ZERO), None);
+
+        assert!(!(Some(ClockTime::ZERO) < ClockTime::NONE));
+        assert_eq!(Some(ClockTime::ZERO).opt_lt(ClockTime::NONE), None);
+        assert_eq!(Some(ClockTime::ZERO).opt_le(ClockTime::NONE), None);
+
+        assert_eq!(CT_3.opt_min(CT_2), Some(CT_2));
+        assert_eq!(CT_3.opt_min(Some(CT_2)), Some(CT_2));
+        assert_eq!(Some(CT_3).opt_min(Some(CT_2)), Some(CT_2));
+        assert_eq!(ClockTime::NONE.opt_min(Some(CT_2)), None);
+        assert_eq!(Some(CT_3).opt_min(ClockTime::NONE), None);
+
+        assert_eq!(CT_3.opt_max(CT_2), Some(CT_3));
+        assert_eq!(CT_3.opt_max(Some(CT_2)), Some(CT_3));
+        assert_eq!(Some(CT_3).opt_max(Some(CT_2)), Some(CT_3));
+        assert_eq!(ClockTime::NONE.opt_max(Some(CT_2)), None);
+        assert_eq!(Some(CT_3).opt_max(ClockTime::NONE), None);
     }
 
     #[test]
@@ -804,4 +856,12 @@ mod tests {
         assert_eq!(format!("{:026}", lots), "0005124095:34:33.709551614");
         assert_eq!(format!("{:+026}", lots), "+005124095:34:33.709551614");
     }
+
+    #[test]
+    fn iter_sum() {
+        let s: ClockTime = vec![ClockTime::from_seconds(1), ClockTime::from_seconds(2)]
+            .into_iter()
+            .sum();
+        assert_eq!(s, ClockTime::from_seconds(3));
+    }
 }
