@@ -9,6 +9,7 @@ use std::mem;
 use std::ops::{Deref, DerefMut};
 use std::ptr;
 
+use glib::object::IsA;
 use glib::translate::*;
 
 mini_object_wrapper!(Query, QueryRef, ffi::GstQuery, || {
@@ -30,6 +31,7 @@ impl QueryRef {
     }
 
     #[doc(alias = "get_mut_structure")]
+    #[doc(alias = "gst_query_writable_structure")]
     pub fn structure_mut(&mut self) -> &mut StructureRef {
         unsafe {
             let structure = ffi::gst_query_writable_structure(self.as_mut_ptr());
@@ -37,14 +39,17 @@ impl QueryRef {
         }
     }
 
+    #[doc(alias = "GST_QUERY_IS_DOWNSTREAM")]
     pub fn is_downstream(&self) -> bool {
         unsafe { ((*self.as_ptr()).type_ as u32) & ffi::GST_QUERY_TYPE_DOWNSTREAM != 0 }
     }
 
+    #[doc(alias = "GST_QUERY_IS_UPSTREAM")]
     pub fn is_upstream(&self) -> bool {
         unsafe { ((*self.as_ptr()).type_ as u32) & ffi::GST_QUERY_TYPE_UPSTREAM != 0 }
     }
 
+    #[doc(alias = "GST_QUERY_IS_SERIALIZED")]
     pub fn is_serialized(&self) -> bool {
         unsafe { ((*self.as_ptr()).type_ as u32) & ffi::GST_QUERY_TYPE_SERIALIZED != 0 }
     }
@@ -137,6 +142,7 @@ unsafe impl<'a> AsMutPtr for &'a mut QueryRef {
 }
 
 #[derive(Debug)]
+#[non_exhaustive]
 pub enum QueryView<T> {
     Position(Position<T>),
     Duration(Duration<T>),
@@ -156,7 +162,6 @@ pub enum QueryView<T> {
     Context(Context<T>),
     Bitrate(Bitrate<T>),
     Other(Other<T>),
-    __NonExhaustive,
 }
 
 macro_rules! declare_concrete_query(
@@ -211,7 +216,7 @@ macro_rules! declare_concrete_query(
         impl From<$name<Query>> for Query {
             fn from(concrete: $name<Query>) -> Self {
                 skip_assert_initialized!();
-                unsafe { from_glib_none(concrete.0.as_mut_ptr()) }
+                concrete.0
             }
         }
     }
@@ -228,6 +233,7 @@ impl Position<Query> {
 
 impl<T: AsPtr> Position<T> {
     #[doc(alias = "get_result")]
+    #[doc(alias = "gst_query_parse_position")]
     pub fn result(&self) -> GenericFormattedValue {
         unsafe {
             let mut fmt = mem::MaybeUninit::uninit();
@@ -240,6 +246,7 @@ impl<T: AsPtr> Position<T> {
     }
 
     #[doc(alias = "get_format")]
+    #[doc(alias = "gst_query_parse_position")]
     pub fn format(&self) -> crate::Format {
         unsafe {
             let mut fmt = mem::MaybeUninit::uninit();
@@ -273,6 +280,7 @@ impl Duration<Query> {
 
 impl<T: AsPtr> Duration<T> {
     #[doc(alias = "get_result")]
+    #[doc(alias = "gst_query_parse_duration")]
     pub fn result(&self) -> GenericFormattedValue {
         unsafe {
             let mut fmt = mem::MaybeUninit::uninit();
@@ -285,6 +293,7 @@ impl<T: AsPtr> Duration<T> {
     }
 
     #[doc(alias = "get_format")]
+    #[doc(alias = "gst_query_parse_duration")]
     pub fn format(&self) -> crate::Format {
         unsafe {
             let mut fmt = mem::MaybeUninit::uninit();
@@ -324,6 +333,7 @@ impl Default for Latency<Query> {
 
 impl<T: AsPtr> Latency<T> {
     #[doc(alias = "get_result")]
+    #[doc(alias = "gst_query_parse_latency")]
     pub fn result(&self) -> (bool, crate::ClockTime, Option<crate::ClockTime>) {
         unsafe {
             let mut live = mem::MaybeUninit::uninit();
@@ -376,6 +386,7 @@ impl Seeking<Query> {
 
 impl<T: AsPtr> Seeking<T> {
     #[doc(alias = "get_result")]
+    #[doc(alias = "gst_query_parse_seeking")]
     pub fn result(&self) -> (bool, GenericFormattedValue, GenericFormattedValue) {
         unsafe {
             let mut fmt = mem::MaybeUninit::uninit();
@@ -399,6 +410,7 @@ impl<T: AsPtr> Seeking<T> {
     }
 
     #[doc(alias = "get_format")]
+    #[doc(alias = "gst_query_parse_seeking")]
     pub fn format(&self) -> crate::Format {
         unsafe {
             let mut fmt = mem::MaybeUninit::uninit();
@@ -447,6 +459,7 @@ impl Segment<Query> {
 
 impl<T: AsPtr> Segment<T> {
     #[doc(alias = "get_result")]
+    #[doc(alias = "gst_query_parse_segment")]
     pub fn result(&self) -> (f64, GenericFormattedValue, GenericFormattedValue) {
         unsafe {
             let mut rate = mem::MaybeUninit::uninit();
@@ -470,6 +483,7 @@ impl<T: AsPtr> Segment<T> {
     }
 
     #[doc(alias = "get_format")]
+    #[doc(alias = "gst_query_parse_segment")]
     pub fn format(&self) -> crate::Format {
         unsafe {
             let mut fmt = mem::MaybeUninit::uninit();
@@ -524,6 +538,7 @@ impl Convert<Query> {
 
 impl<T: AsPtr> Convert<T> {
     #[doc(alias = "get_result")]
+    #[doc(alias = "gst_query_parse_convert")]
     pub fn result(&self) -> (GenericFormattedValue, GenericFormattedValue) {
         unsafe {
             let mut src_fmt = mem::MaybeUninit::uninit();
@@ -545,6 +560,7 @@ impl<T: AsPtr> Convert<T> {
         }
     }
 
+    #[doc(alias = "gst_query_parse_convert")]
     pub fn get(&self) -> (GenericFormattedValue, crate::Format) {
         unsafe {
             let mut src_fmt = mem::MaybeUninit::uninit();
@@ -601,6 +617,8 @@ impl Default for Formats<Query> {
 
 impl<T: AsPtr> Formats<T> {
     #[doc(alias = "get_result")]
+    #[doc(alias = "gst_query_parse_n_formats")]
+    #[doc(alias = "gst_query_parse_nth_format")]
     pub fn result(&self) -> Vec<crate::Format> {
         unsafe {
             let mut n = mem::MaybeUninit::uninit();
@@ -620,6 +638,7 @@ impl<T: AsPtr> Formats<T> {
 }
 
 impl<T: AsMutPtr> Formats<T> {
+    #[doc(alias = "gst_query_set_formats")]
     #[doc(alias = "gst_query_set_formatsv")]
     pub fn set(&mut self, formats: &[crate::Format]) {
         unsafe {
@@ -644,6 +663,7 @@ impl Buffering<Query> {
 
 impl<T: AsPtr> Buffering<T> {
     #[doc(alias = "get_format")]
+    #[doc(alias = "gst_query_parse_buffering_range")]
     pub fn format(&self) -> crate::Format {
         unsafe {
             let mut fmt = mem::MaybeUninit::uninit();
@@ -729,6 +749,7 @@ impl<T: AsPtr> Buffering<T> {
 
     #[doc(alias = "get_ranges")]
     #[doc(alias = "gst_query_get_n_buffering_ranges")]
+    #[doc(alias = "gst_query_parse_nth_buffering_range")]
     pub fn ranges(&self) -> Vec<(GenericFormattedValue, GenericFormattedValue)> {
         unsafe {
             let mut fmt = mem::MaybeUninit::uninit();
@@ -766,12 +787,14 @@ impl<T: AsPtr> Buffering<T> {
 }
 
 impl<T: AsMutPtr> Buffering<T> {
+    #[doc(alias = "gst_query_set_buffering_percent")]
     pub fn set_percent(&mut self, busy: bool, percent: i32) {
         unsafe {
             ffi::gst_query_set_buffering_percent(self.0.as_mut_ptr(), busy.into_glib(), percent);
         }
     }
 
+    #[doc(alias = "gst_query_set_buffering_range")]
     pub fn set_range<V: Into<GenericFormattedValue>>(
         &mut self,
         start: V,
@@ -795,6 +818,7 @@ impl<T: AsMutPtr> Buffering<T> {
         }
     }
 
+    #[doc(alias = "gst_query_set_buffering_stats")]
     pub fn set_stats(
         &mut self,
         mode: crate::BufferingMode,
@@ -814,6 +838,7 @@ impl<T: AsMutPtr> Buffering<T> {
         }
     }
 
+    #[doc(alias = "gst_query_add_buffering_range")]
     pub fn add_buffering_ranges<V: Into<GenericFormattedValue> + Copy>(
         &mut self,
         ranges: &[(V, V)],
@@ -893,15 +918,15 @@ impl<T: AsPtr> Uri<T> {
 
 impl<T: AsMutPtr> Uri<T> {
     #[doc(alias = "gst_query_set_uri")]
-    pub fn set_uri<'b, U: Into<&'b str>>(&mut self, uri: U) {
-        let uri = uri.into();
+    pub fn set_uri(&mut self, uri: &str) {
         unsafe {
             ffi::gst_query_set_uri(self.0.as_mut_ptr(), uri.to_glib_none().0);
         }
     }
 
-    pub fn set_redirection<'b, U: Into<&'b str>>(&mut self, uri: U, permanent: bool) {
-        let uri = uri.into();
+    #[doc(alias = "gst_query_set_uri_redirection")]
+    #[doc(alias = "gst_query_set_uri_redirection_permanent")]
+    pub fn set_redirection(&mut self, uri: &str, permanent: bool) {
         unsafe {
             ffi::gst_query_set_uri_redirection(self.0.as_mut_ptr(), uri.to_glib_none().0);
             ffi::gst_query_set_uri_redirection_permanent(
@@ -927,6 +952,7 @@ impl Allocation<Query> {
 }
 
 impl<T: AsPtr> Allocation<T> {
+    #[doc(alias = "gst_query_parse_allocation")]
     pub fn get(&self) -> (&crate::CapsRef, bool) {
         unsafe {
             let mut caps = ptr::null_mut();
@@ -940,6 +966,7 @@ impl<T: AsPtr> Allocation<T> {
         }
     }
 
+    #[doc(alias = "gst_query_parse_allocation")]
     pub fn get_owned(&self) -> (crate::Caps, bool) {
         unsafe {
             let (caps, need_pool) = self.get();
@@ -947,8 +974,32 @@ impl<T: AsPtr> Allocation<T> {
         }
     }
 
+    #[doc(alias = "gst_allocation_params")]
+    #[doc(alias = "gst_query_get_n_allocation_params")]
+    #[doc(alias = "gst_query_parse_nth_allocation_param")]
+    pub fn allocation_params(&self) -> Vec<(Option<crate::Allocator>, crate::AllocationParams)> {
+        unsafe {
+            let n = ffi::gst_query_get_n_allocation_params(self.0.as_ptr());
+            let mut params = Vec::with_capacity(n as usize);
+            for i in 0..n {
+                let mut allocator = ptr::null_mut();
+                let mut p = mem::MaybeUninit::uninit();
+                ffi::gst_query_parse_nth_allocation_param(
+                    self.0.as_ptr(),
+                    i,
+                    &mut allocator,
+                    p.as_mut_ptr(),
+                );
+                params.push((from_glib_full(allocator), from_glib(p.assume_init())));
+            }
+
+            params
+        }
+    }
+
     #[doc(alias = "get_allocation_pools")]
     #[doc(alias = "gst_query_get_n_allocation_pools")]
+    #[doc(alias = "gst_query_parse_nth_allocation_pool")]
     pub fn allocation_pools(&self) -> Vec<(Option<crate::BufferPool>, u32, u32, u32)> {
         unsafe {
             let n = ffi::gst_query_get_n_allocation_pools(self.0.as_ptr());
@@ -981,6 +1032,7 @@ impl<T: AsPtr> Allocation<T> {
 
     #[doc(alias = "get_allocation_metas")]
     #[doc(alias = "gst_query_get_n_allocation_metas")]
+    #[doc(alias = "gst_query_parse_nth_allocation_meta")]
     pub fn allocation_metas(&self) -> Vec<(glib::Type, Option<&crate::StructureRef>)> {
         unsafe {
             let n = ffi::gst_query_get_n_allocation_metas(self.0.as_ptr());
@@ -1026,7 +1078,7 @@ impl<T: AsMutPtr> Allocation<T> {
     #[doc(alias = "gst_query_add_allocation_pool")]
     pub fn add_allocation_pool(
         &mut self,
-        pool: Option<&crate::BufferPool>,
+        pool: Option<&impl IsA<crate::BufferPool>>,
         size: u32,
         min_buffers: u32,
         max_buffers: u32,
@@ -1034,7 +1086,7 @@ impl<T: AsMutPtr> Allocation<T> {
         unsafe {
             ffi::gst_query_add_allocation_pool(
                 self.0.as_mut_ptr(),
-                pool.to_glib_none().0,
+                pool.to_glib_none().0 as *mut ffi::GstBufferPool,
                 size,
                 min_buffers,
                 max_buffers,
@@ -1046,16 +1098,18 @@ impl<T: AsMutPtr> Allocation<T> {
     pub fn set_nth_allocation_pool(
         &mut self,
         idx: u32,
-        pool: Option<&crate::BufferPool>,
+        pool: Option<&impl IsA<crate::BufferPool>>,
         size: u32,
         min_buffers: u32,
         max_buffers: u32,
     ) {
         unsafe {
+            let n = ffi::gst_query_get_n_allocation_pools(self.0.as_ptr());
+            assert!(idx < n);
             ffi::gst_query_set_nth_allocation_pool(
                 self.0.as_mut_ptr(),
                 idx,
-                pool.to_glib_none().0,
+                pool.to_glib_none().0 as *mut ffi::GstBufferPool,
                 size,
                 min_buffers,
                 max_buffers,
@@ -1066,10 +1120,55 @@ impl<T: AsMutPtr> Allocation<T> {
     #[doc(alias = "gst_query_remove_nth_allocation_pool")]
     pub fn remove_nth_allocation_pool(&mut self, idx: u32) {
         unsafe {
+            let n = ffi::gst_query_get_n_allocation_pools(self.0.as_ptr());
+            assert!(idx < n);
             ffi::gst_query_remove_nth_allocation_pool(self.0.as_mut_ptr(), idx);
         }
     }
 
+    #[doc(alias = "gst_query_add_allocation_param")]
+    pub fn add_allocation_param(
+        &mut self,
+        allocator: Option<&impl IsA<crate::Allocator>>,
+        params: crate::AllocationParams,
+    ) {
+        unsafe {
+            ffi::gst_query_add_allocation_param(
+                self.0.as_mut_ptr(),
+                allocator.to_glib_none().0 as *mut ffi::GstAllocator,
+                params.as_ptr(),
+            );
+        }
+    }
+
+    #[doc(alias = "gst_query_set_nth_allocation_param")]
+    pub fn set_nth_allocation_param(
+        &mut self,
+        idx: u32,
+        allocator: Option<&impl IsA<crate::Allocator>>,
+        params: crate::AllocationParams,
+    ) {
+        unsafe {
+            let n = ffi::gst_query_get_n_allocation_params(self.0.as_ptr());
+            assert!(idx < n);
+            ffi::gst_query_set_nth_allocation_param(
+                self.0.as_mut_ptr(),
+                idx,
+                allocator.to_glib_none().0 as *mut ffi::GstAllocator,
+                params.as_ptr(),
+            );
+        }
+    }
+
+    #[doc(alias = "gst_query_remove_nth_allocation_param")]
+    pub fn remove_nth_allocation_param(&mut self, idx: u32) {
+        unsafe {
+            let n = ffi::gst_query_get_n_allocation_params(self.0.as_ptr());
+            assert!(idx < n);
+            ffi::gst_query_remove_nth_allocation_param(self.0.as_mut_ptr(), idx);
+        }
+    }
+
     #[doc(alias = "gst_query_add_allocation_meta")]
     pub fn add_allocation_meta<U: crate::MetaAPI>(
         &mut self,
@@ -1091,6 +1190,8 @@ impl<T: AsMutPtr> Allocation<T> {
     #[doc(alias = "gst_query_remove_nth_allocation_meta")]
     pub fn remove_nth_allocation_meta(&mut self, idx: u32) {
         unsafe {
+            let n = ffi::gst_query_get_n_allocation_metas(self.0.as_ptr());
+            assert!(idx < n);
             ffi::gst_query_remove_nth_allocation_meta(self.0.as_mut_ptr(), idx);
         }
     }
@@ -1156,6 +1257,7 @@ impl<T: AsPtr> Scheduling<T> {
     }
 
     #[doc(alias = "get_result")]
+    #[doc(alias = "gst_query_parse_scheduling")]
     pub fn result(&self) -> (crate::SchedulingFlags, i32, i32, i32) {
         unsafe {
             let mut flags = mem::MaybeUninit::uninit();
@@ -1182,6 +1284,7 @@ impl<T: AsPtr> Scheduling<T> {
 }
 
 impl<T: AsMutPtr> Scheduling<T> {
+    #[doc(alias = "gst_query_add_scheduling_mode")]
     pub fn add_scheduling_modes(&mut self, modes: &[crate::PadMode]) {
         unsafe {
             for mode in modes {
@@ -1215,24 +1318,61 @@ impl AcceptCaps<Query> {
             )))
         }
     }
-}
 
-impl<T: AsPtr> AcceptCaps<T> {
     #[doc(alias = "get_caps")]
     #[doc(alias = "gst_query_parse_accept_caps")]
     pub fn caps(&self) -> &crate::CapsRef {
         unsafe {
             let mut caps = ptr::null_mut();
-            ffi::gst_query_parse_accept_caps(self.0.as_ptr(), &mut caps);
+            ffi::gst_query_parse_accept_caps(AsPtr::as_ptr(&self.0), &mut caps);
             crate::CapsRef::from_ptr(caps)
         }
     }
 
     #[doc(alias = "get_caps_owned")]
+    #[doc(alias = "gst_query_parse_accept_caps")]
     pub fn caps_owned(&self) -> crate::Caps {
         unsafe { from_glib_none(self.caps().as_ptr()) }
     }
+}
 
+impl<'a> AcceptCaps<&'a QueryRef> {
+    #[doc(alias = "get_caps")]
+    #[doc(alias = "gst_query_parse_accept_caps")]
+    pub fn caps(&self) -> &'a crate::CapsRef {
+        unsafe {
+            let mut caps = ptr::null_mut();
+            ffi::gst_query_parse_accept_caps(AsPtr::as_ptr(&self.0), &mut caps);
+            crate::CapsRef::from_ptr(caps)
+        }
+    }
+
+    #[doc(alias = "get_caps_owned")]
+    #[doc(alias = "gst_query_parse_accept_caps")]
+    pub fn caps_owned(&self) -> crate::Caps {
+        unsafe { from_glib_none(self.caps().as_ptr()) }
+    }
+}
+
+impl<'a> AcceptCaps<&'a mut QueryRef> {
+    #[doc(alias = "get_caps")]
+    #[doc(alias = "gst_query_parse_accept_caps")]
+    pub fn caps(&self) -> &'a crate::CapsRef {
+        unsafe {
+            let mut caps = ptr::null_mut();
+            ffi::gst_query_parse_accept_caps(AsPtr::as_ptr(&self.0), &mut caps);
+            crate::CapsRef::from_ptr(caps)
+        }
+    }
+
+    #[doc(alias = "get_caps_owned")]
+    #[doc(alias = "gst_query_parse_accept_caps")]
+    pub fn caps_owned(&self) -> crate::Caps {
+        unsafe { from_glib_none(self.caps().as_ptr()) }
+    }
+}
+
+impl<T: AsPtr> AcceptCaps<T> {
     #[doc(alias = "get_result")]
     #[doc(alias = "gst_query_parse_accept_caps_result")]
     pub fn result(&self) -> bool {
@@ -1245,6 +1385,7 @@ impl<T: AsPtr> AcceptCaps<T> {
 }
 
 impl<T: AsMutPtr> AcceptCaps<T> {
+    #[doc(alias = "gst_query_set_accept_caps_result")]
     pub fn set_result(&mut self, accepted: bool) {
         unsafe {
             ffi::gst_query_set_accept_caps_result(self.0.as_mut_ptr(), accepted.into_glib());
@@ -1267,6 +1408,7 @@ impl Caps<Query> {
 
 impl<T: AsPtr> Caps<T> {
     #[doc(alias = "get_filter")]
+    #[doc(alias = "gst_query_parse_caps")]
     pub fn filter(&self) -> Option<&crate::CapsRef> {
         unsafe {
             let mut caps = ptr::null_mut();
@@ -1280,6 +1422,7 @@ impl<T: AsPtr> Caps<T> {
     }
 
     #[doc(alias = "get_filter_owned")]
+    #[doc(alias = "gst_query_parse_caps")]
     pub fn filter_owned(&self) -> Option<crate::Caps> {
         unsafe { self.filter().map(|caps| from_glib_none(caps.as_ptr())) }
     }
@@ -1299,12 +1442,14 @@ impl<T: AsPtr> Caps<T> {
     }
 
     #[doc(alias = "get_result_owned")]
+    #[doc(alias = "gst_query_parse_caps_result")]
     pub fn result_owned(&self) -> Option<crate::Caps> {
         unsafe { self.result().map(|caps| from_glib_none(caps.as_ptr())) }
     }
 }
 
 impl<T: AsMutPtr> Caps<T> {
+    #[doc(alias = "gst_query_set_caps_result")]
     pub fn set_result(&mut self, caps: &crate::Caps) {
         unsafe {
             ffi::gst_query_set_caps_result(self.0.as_mut_ptr(), caps.as_mut_ptr());
@@ -1338,15 +1483,13 @@ impl Context<Query> {
             )))
         }
     }
-}
 
-impl<T: AsPtr> Context<T> {
     #[doc(alias = "get_context")]
     #[doc(alias = "gst_query_parse_context")]
     pub fn context(&self) -> Option<&crate::ContextRef> {
         unsafe {
             let mut context = ptr::null_mut();
-            ffi::gst_query_parse_context(self.0.as_ptr(), &mut context);
+            ffi::gst_query_parse_context(AsPtr::as_ptr(&self.0), &mut context);
             if context.is_null() {
                 None
             } else {
@@ -1356,6 +1499,7 @@ impl<T: AsPtr> Context<T> {
     }
 
     #[doc(alias = "get_context_owned")]
+    #[doc(alias = "gst_query_parse_context")]
     pub fn context_owned(&self) -> Option<crate::Context> {
         unsafe {
             self.context()
@@ -1368,7 +1512,77 @@ impl<T: AsPtr> Context<T> {
     pub fn context_type(&self) -> &str {
         unsafe {
             let mut context_type = ptr::null();
-            ffi::gst_query_parse_context_type(self.0.as_ptr(), &mut context_type);
+            ffi::gst_query_parse_context_type(AsPtr::as_ptr(&self.0), &mut context_type);
+            CStr::from_ptr(context_type).to_str().unwrap()
+        }
+    }
+}
+
+impl<'a> Context<&'a QueryRef> {
+    #[doc(alias = "get_context")]
+    #[doc(alias = "gst_query_parse_context")]
+    pub fn context(&self) -> Option<&'a crate::ContextRef> {
+        unsafe {
+            let mut context = ptr::null_mut();
+            ffi::gst_query_parse_context(AsPtr::as_ptr(&self.0), &mut context);
+            if context.is_null() {
+                None
+            } else {
+                Some(crate::ContextRef::from_ptr(context))
+            }
+        }
+    }
+
+    #[doc(alias = "get_context_owned")]
+    #[doc(alias = "gst_query_parse_context")]
+    pub fn context_owned(&self) -> Option<crate::Context> {
+        unsafe {
+            self.context()
+                .map(|context| from_glib_none(context.as_ptr()))
+        }
+    }
+
+    #[doc(alias = "get_context_type")]
+    #[doc(alias = "gst_query_parse_context_type")]
+    pub fn context_type(&self) -> &'a str {
+        unsafe {
+            let mut context_type = ptr::null();
+            ffi::gst_query_parse_context_type(AsPtr::as_ptr(&self.0), &mut context_type);
+            CStr::from_ptr(context_type).to_str().unwrap()
+        }
+    }
+}
+
+impl<'a> Context<&'a mut QueryRef> {
+    #[doc(alias = "get_context")]
+    #[doc(alias = "gst_query_parse_context")]
+    pub fn context(&self) -> Option<&'a crate::ContextRef> {
+        unsafe {
+            let mut context = ptr::null_mut();
+            ffi::gst_query_parse_context(AsPtr::as_ptr(&self.0), &mut context);
+            if context.is_null() {
+                None
+            } else {
+                Some(crate::ContextRef::from_ptr(context))
+            }
+        }
+    }
+
+    #[doc(alias = "get_context_owned")]
+    #[doc(alias = "gst_query_parse_context")]
+    pub fn context_owned(&self) -> Option<crate::Context> {
+        unsafe {
+            self.context()
+                .map(|context| from_glib_none(context.as_ptr()))
+        }
+    }
+
+    #[doc(alias = "get_context_type")]
+    #[doc(alias = "gst_query_parse_context_type")]
+    pub fn context_type(&self) -> &'a str {
+        unsafe {
+            let mut context_type = ptr::null();
+            ffi::gst_query_parse_context_type(AsPtr::as_ptr(&self.0), &mut context_type);
             CStr::from_ptr(context_type).to_str().unwrap()
         }
     }
@@ -1434,7 +1648,6 @@ declare_concrete_query!(Other, T);
 mod tests {
     use super::*;
     use crate::ClockTime;
-    use std::convert::TryInto;
 
     #[test]
     fn test_writability() {
