@@ -100,16 +100,12 @@ impl<T: BinImpl> BinImplExt for T {
 
 unsafe impl<T: BinImpl> IsSubclassable<T> for Bin {
     fn class_init(klass: &mut glib::Class<Self>) {
-        <crate::Element as IsSubclassable<T>>::class_init(klass);
+        Self::parent_class_init::<T>(klass);
         let klass = klass.as_mut();
         klass.add_element = Some(bin_add_element::<T>);
         klass.remove_element = Some(bin_remove_element::<T>);
         klass.handle_message = Some(bin_handle_message::<T>);
     }
-
-    fn instance_init(instance: &mut glib::subclass::InitializingObject<T>) {
-        <crate::Element as IsSubclassable<T>>::instance_init(instance);
-    }
 }
 
 unsafe extern "C" fn bin_add_element<T: BinImpl>(
@@ -117,7 +113,7 @@ unsafe extern "C" fn bin_add_element<T: BinImpl>(
     element: *mut ffi::GstElement,
 ) -> glib::ffi::gboolean {
     let instance = &*(ptr as *mut T::Instance);
-    let imp = instance.impl_();
+    let imp = instance.imp();
     let wrap: Borrowed<Bin> = from_glib_borrow(ptr);
 
     panic_to_error!(&wrap, imp.panicked(), false, {
@@ -137,7 +133,7 @@ unsafe extern "C" fn bin_remove_element<T: BinImpl>(
     element: *mut ffi::GstElement,
 ) -> glib::ffi::gboolean {
     let instance = &*(ptr as *mut T::Instance);
-    let imp = instance.impl_();
+    let imp = instance.imp();
     let wrap: Borrowed<Bin> = from_glib_borrow(ptr);
 
     // If we get a floating reference passed simply return FALSE here. It can't be
@@ -166,7 +162,7 @@ unsafe extern "C" fn bin_handle_message<T: BinImpl>(
     message: *mut ffi::GstMessage,
 ) {
     let instance = &*(ptr as *mut T::Instance);
-    let imp = instance.impl_();
+    let imp = instance.imp();
     let wrap: Borrowed<Bin> = from_glib_borrow(ptr);
 
     panic_to_error!(&wrap, imp.panicked(), (), {
